@@ -38,7 +38,7 @@ HOME = os.path.expanduser("~")
 UI_FILE = '/usr/share/linuxmint/mintbackup/mintbackup.ui'
 META_FILE = ".meta.mint"
 
-BACKUP_DIR = os.path.join(GLib.get_user_special_dir(GLib.USER_DIRECTORY_DOCUMENTS), _("Backups"))
+BACKUP_DIR = os.path.join(GLib.get_user_special_dir(GLib.UserDirectory.DIRECTORY_DOCUMENTS), _("Backups"))
 if not os.path.exists(BACKUP_DIR):
     print("Creating backup directory in %s" % BACKUP_DIR)
     os.makedirs(BACKUP_DIR)
@@ -62,7 +62,7 @@ class MintBackup:
         self.builder.set_translation_domain(APP)
         self.builder.add_from_file(UI_FILE)
 
-        self.settings = Gio.Settings("com.linuxmint.backup")
+        self.settings = Gio.Settings(schema="com.linuxmint.backup")
         self.follow_links = self.settings.get_boolean("backup-follow-symlink")
 
         self.notebook = self.builder.get_object("notebook1")
@@ -221,7 +221,8 @@ class MintBackup:
 
     def add_item_to_treeview(self, widget, treeview, icon, mode, show_hidden=False):
         # Add a file or directory to treeview
-        dialog = Gtk.FileChooserDialog(_("Backup Tool"), self.main_window, mode, (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL, Gtk.STOCK_OPEN, Gtk.ResponseType.OK))
+        dialog = Gtk.FileChooserDialog(title=("Backup Tool"), parent=self.main_window, action=mode)
+        dialog.add_buttons(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL, Gtk.STOCK_OPEN, Gtk.ResponseType.OK)
         dialog.set_current_folder(self.home_directory)
         dialog.set_select_multiple(True)
         dialog.set_show_hidden(show_hidden)
@@ -446,7 +447,7 @@ class MintBackup:
         try:
             rel_path = os.path.relpath(path)
             GLib.idle_add(self.set_progress, rel_path)
-            self.tar_archive.add(path, arcname=rel_path, recursive=False, exclude=None)
+            self.tar_archive.add(path, arcname=rel_path, recursive=False)
             self.archived_files += 1
         except Exception as detail:
             print(detail)
@@ -530,7 +531,7 @@ class MintBackup:
             try:
                 self.tar_archive = tarfile.open(name=self.temp_filename, dereference=self.follow_links, mode=backup_mode, bufsize=1024)
                 mintfile = os.path.join(self.backup_dest, META_FILE)
-                self.tar_archive.add(mintfile, arcname=META_FILE, recursive=False, exclude=None)
+                self.tar_archive.add(mintfile, arcname=META_FILE, recursive=False)
             except Exception as detail:
                 print(detail)
                 self.errors.append([str(detail), None])
